==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/Binary/SkipBits.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46Binary_46hs_95skipBits_35	((void*)startLabel+12)
#define CT_v195	((void*)startLabel+44)
#define F0_NHC_46Binary_46hs_95skipBits_35	((void*)startLabel+52)
#define FN_NHC_46Binary_46hs_95skipBits	((void*)startLabel+64)
#define CT_v197	((void*)startLabel+88)
#define CF_NHC_46Binary_46hs_95skipBits	((void*)startLabel+96)
#define CT_v199	((void*)startLabel+156)
#define FN_LAMBDA192	((void*)startLabel+192)
#define CT_v201	((void*)startLabel+216)
#define F0_LAMBDA192	((void*)startLabel+224)
#define ST_v196	((void*)startLabel+232)
#define ST_v194	((void*)startLabel+255)
#define ST_v198	((void*)startLabel+279)
#define ST_v200	((void*)startLabel+299)
extern Node TM_NHC_46Binary[];
void FR_NHC_46Binary_46hs_95skipBits_35(void);
extern Node TM_NHC_46Binary[];
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node TM_NHC_46Binary[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_NHC_46Binary[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v195)
,	/* FN_NHC_46Binary_46hs_95skipBits_35: (byte 0) */
  useLabel(TM_NHC_46Binary)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46Binary_46hs_95skipBits_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90022
, useLabel(ST_v194)
,	/* CT_v195: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46Binary_46hs_95skipBits_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46Binary_46hs_95skipBits_35),2)
, bytes2word(0,0,0,0)
, useLabel(CT_v197)
,	/* FN_NHC_46Binary_46hs_95skipBits: (byte 0) */
  useLabel(TM_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90022
, useLabel(ST_v196)
,	/* CT_v197: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46Binary_46hs_95skipBits: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46Binary_46hs_95skipBits))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46Binary_46hs_95skipBits_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v199)
,};
Node FN_NHC_46Binary_46skipBits[] = {
  useLabel(TM_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_I5,PUSH_HEAP,HEAP_CVAL_P1,6)
, bytes2word(HEAP_OFF_N1,6,HEAP_OFF_N1,3)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 120001
, useLabel(ST_v198)
,	/* CT_v199: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46Binary_46skipBits[] = {
  CAPTAG(useLabel(FN_NHC_46Binary_46skipBits),2)
, VAPTAG(useLabel(FN_NHC_46Binary_46hs_95skipBits))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA192),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v201)
,	/* FN_LAMBDA192: (byte 0) */
  useLabel(TMSUB_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 130014
, useLabel(ST_v200)
,	/* CT_v201: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA192: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA192),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* ST_v196: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,104)
, bytes2word(115,95,115,107)
, bytes2word(105,112,66,105)
,	/* ST_v194: (byte 3) */
  bytes2word(116,115,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,97,114)
, bytes2word(121,46,104,115)
, bytes2word(95,115,107,105)
, bytes2word(112,66,105,116)
,	/* ST_v198: (byte 3) */
  bytes2word(115,35,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,97,114)
, bytes2word(121,46,115,107)
, bytes2word(105,112,66,105)
,	/* ST_v200: (byte 3) */
  bytes2word(116,115,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,97,114)
, bytes2word(121,46,115,107)
, bytes2word(105,112,66,105)
, bytes2word(116,115,58,49)
, bytes2word(51,58,49,52)
, bytes2word(0,0,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_skipBits" NHC.Binary.hs_skipBits# 2 :: FFI.ForeignObj -> Prelude.Int -> Prelude.() */
extern void hs_skipBits(void*,HsInt);
#ifdef PROFILE
static SInfo pf_hs_skipBits = {"NHC.Binary","NHC.Binary.hs_skipBits#","Prelude.()"};
#endif
C_HEADER(FR_NHC_46Binary_46hs_95skipBits_35) {
  NodePtr nodeptr;
  void* arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  hs_skipBits(arg1,arg2);

  nodeptr = nhc_mkUnit();
  INIT_PROFINFO(nodeptr,&pf_hs_skipBits);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/Binary/SkipBits.z.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46Binary_46hs_95skipBits_35	((void*)startLabel+12)
#define CT_v199	((void*)startLabel+44)
#define F0_NHC_46Binary_46hs_95skipBits_35	((void*)startLabel+52)
#define FN_NHC_46Binary_46hs_95skipBits	((void*)startLabel+64)
#define CT_v201	((void*)startLabel+88)
#define CF_NHC_46Binary_46hs_95skipBits	((void*)startLabel+96)
#define CT_v203	((void*)startLabel+156)
#define FN_LAMBDA196	((void*)startLabel+192)
#define CT_v205	((void*)startLabel+216)
#define F0_LAMBDA196	((void*)startLabel+224)
#define ST_v200	((void*)startLabel+232)
#define ST_v198	((void*)startLabel+255)
#define ST_v202	((void*)startLabel+279)
#define ST_v204	((void*)startLabel+299)
extern Node TM_NHC_46Binary[];
void FR_NHC_46Binary_46hs_95skipBits_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok2[];
extern Node FN_NHC_46Internal_46_95apply2[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node TMSUB_NHC_46Binary[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v199)
,	/* FN_NHC_46Binary_46hs_95skipBits_35: (byte 0) */
  useLabel(TM_NHC_46Binary)
, bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PUSH_ARG_I2)
, bytes2word(EVAL,POP_I1,PRIMITIVE,NOP)
, useLabel(FR_NHC_46Binary_46hs_95skipBits_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90001
, useLabel(ST_v198)
,	/* CT_v199: (byte 0) */
  HW(0,2)
, 0
,	/* F0_NHC_46Binary_46hs_95skipBits_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46Binary_46hs_95skipBits_35),2)
, bytes2word(0,0,0,0)
, useLabel(CT_v201)
,	/* FN_NHC_46Binary_46hs_95skipBits: (byte 0) */
  useLabel(TM_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_CVAL_I4)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 90001
, useLabel(ST_v200)
,	/* CT_v201: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46Binary_46hs_95skipBits: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46Binary_46hs_95skipBits))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok2))
, useLabel(F0_NHC_46Binary_46hs_95skipBits_35)
, bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v203)
,};
Node FN_NHC_46Binary_46skipBits[] = {
  useLabel(TM_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,HEAP_CVAL_I3,HEAP_CVAL_I4,HEAP_OFF_N1)
, bytes2word(2,HEAP_ARG_ARG,1,2)
, bytes2word(HEAP_CVAL_I5,PUSH_HEAP,HEAP_CVAL_P1,6)
, bytes2word(HEAP_OFF_N1,6,HEAP_OFF_N1,3)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 120001
, useLabel(ST_v202)
,	/* CT_v203: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_NHC_46Binary_46skipBits[] = {
  CAPTAG(useLabel(FN_NHC_46Binary_46skipBits),2)
, VAPTAG(useLabel(FN_NHC_46Binary_46hs_95skipBits))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply2))
, CAPTAG(useLabel(FN_LAMBDA196),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v205)
,	/* FN_LAMBDA196: (byte 0) */
  useLabel(TMSUB_NHC_46Binary)
, bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_I3,HEAP_ARG)
, bytes2word(1,RETURN_EVAL,ENDCODE,0)
, bytes2word(0,0,0,0)
, 130014
, useLabel(ST_v204)
,	/* CT_v205: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA196: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA196),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,	/* ST_v200: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,97)
, bytes2word(114,121,46,104)
, bytes2word(115,95,115,107)
, bytes2word(105,112,66,105)
,	/* ST_v198: (byte 3) */
  bytes2word(116,115,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,97,114)
, bytes2word(121,46,104,115)
, bytes2word(95,115,107,105)
, bytes2word(112,66,105,116)
,	/* ST_v202: (byte 3) */
  bytes2word(115,35,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,97,114)
, bytes2word(121,46,115,107)
, bytes2word(105,112,66,105)
,	/* ST_v204: (byte 3) */
  bytes2word(116,115,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,97,114)
, bytes2word(121,46,115,107)
, bytes2word(105,112,66,105)
, bytes2word(116,115,58,49)
, bytes2word(51,58,49,52)
, bytes2word(45,49,51,58)
, bytes2word(51,51,0,0)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_skipBits" NHC.Binary.hs_skipBits# 2 :: FFI.ForeignObj -> Prelude.Int -> Prelude.() */
extern void hs_skipBits(void*,HsInt);
#ifdef PROFILE
static SInfo pf_NHC_46Binary_46hs_95skipBits_35 = {"NHC.Binary","NHC.Binary.hs_skipBits#","Prelude.()"};
#endif
C_HEADER(FR_NHC_46Binary_46hs_95skipBits_35) {
  NodePtr nodeptr;
  void* arg1;
  HsInt arg2;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));
  nodeptr = C_GETARG1(2);
  IND_REMOVE(nodeptr);
  arg2 = (HsInt)GET_INT_VALUE(nodeptr);

  hs_skipBits(arg1,arg2);

  nodeptr = nhc_mkUnit();
  INIT_PROFINFO(nodeptr,&pf_NHC_46Binary_46hs_95skipBits_35);
  C_RETURN(nodeptr);
}
